"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const redis = require("redis");
class LetsEncryptRedisChallenge {
    constructor(opts) {
        this._options = {
            prefix: 'letsencrypt-acme-challenge'
        };
        Object.assign(this._options, opts);
    }
    getOptions() {
        return this._options;
    }
    set(args, domain, token, secret, done) {
        const client = this._createClient();
        client.set(`${this._options.prefix}:${domain}:${token}`, secret, (err) => {
            client.quit();
            done(err);
        });
    }
    get(defaults, domain, token, done) {
        const client = this._createClient();
        client.get(`${this._options.prefix}:${domain}:${token}`, (err, secret) => {
            client.quit();
            // strict null check
            if (secret === null) {
                return done();
            }
            else {
                done(null, secret);
            }
        });
    }
    remove(defaults, domain, token, done) {
        const client = this._createClient();
        client.del(`${this._options.prefix}:${domain}:${token}`, (err) => {
            client.quit();
            done(err);
        });
    }
    _createClient() {
        return redis.createClient(this._options.redisOptions);
    }
    static create(opts = {}) {
        return new LetsEncryptRedisChallenge(opts);
    }
}
exports.LetsEncryptRedisChallenge = LetsEncryptRedisChallenge;
